# This spec file is derived from RHEL 9.1 GA package. It hopefully
# should get obsolete with RHEL 9.2 GA when libpagemaker-devel got included.
# Upstream: https://gitlab.com/redhat/centos-stream/rpms/libpagemaker
%global rhel_name libpagemaker
%global rhel_release 13
%global epel_release 1
%global _debugsource_template %{nil}

%global apiversion 0.0

Name: libpagemaker-epel
Version: 0.0.4
Release: 0.%{rhel_release}%{?dist}.%{epel_release}
Summary: A library for import of Adobe PageMaker documents

License: MPLv2.0
URL: http://wiki.documentfoundation.org/DLP/Libraries/libpagemaker
Source: http://dev-www.libreoffice.org/src/%{rhel_name}/%{rhel_name}-%{version}.tar.xz

BuildRequires: boost-devel
BuildRequires: doxygen
BuildRequires: gcc-c++
BuildRequires: help2man
BuildRequires: pkgconfig(librevenge-0.0)
BuildRequires: pkgconfig(librevenge-generators-0.0)
BuildRequires: pkgconfig(librevenge-stream-0.0)
BuildRequires: make

%description
libpagemaker is library providing ability to interpret and import
Adobe PageMaker documents into various applications.

%package -n %{rhel_name}-devel
Summary: Development files for %{rhel_name}
Requires: %{rhel_name}%{?_isa} = %{version}

%description -n %{rhel_name}-devel
The %{rhel_name}-devel package contains libraries and header files for
developing applications that use %{rhel_name}.

%prep
%autosetup -n %{rhel_name}-%{version} -p1

%build
%configure --disable-silent-rules --disable-static --disable-werror
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make_build

%install
%make_install
rm -f %{buildroot}/%{_libdir}/*.la
# we install API docs directly from build
rm -rf %{buildroot}/%{_docdir}/%{rhel_name}

# generate and install man pages
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
for tool in pmd2raw pmd2svg pmd2text; do
    help2man -N -S '%{rhel_name} %{version}' -o ${tool}.1 %{buildroot}%{_bindir}/${tool}
done
install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 pmd2*.1 %{buildroot}/%{_mandir}/man1

# Remove files shipped in RHEL 9
rm -f $RPM_BUILD_ROOT%{_libdir}/%{rhel_name}-%{apiversion}.so.*
rm -rf $RPM_BUILD_ROOT{%{_bindir},%{_mandir}}

%ldconfig_scriptlets

%files -n %{rhel_name}-devel
%doc ChangeLog
%{_includedir}/%{rhel_name}-%{apiversion}
%{_libdir}/%{rhel_name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{rhel_name}-%{apiversion}.pc

%changelog
* Sat Dec 10 2022 Robert Scheck <robert@fedoraproject.org> - 0.1.7-0.3.el9.1
- Transformed libpagemaker-0.0.4-13.el9 into libpagemaker-epel to achieve
  the missing libpagemaker-devel package for EPEL 9 until it's available
  with RHEL 9.2
  Related: rhbz#2144656

* Mon Aug 09 2021 Mohan Boddu <mboddu@redhat.com> - 0.0.4-13
- Rebuilt for IMA sigs, glibc 2.34, aarch64 flags
  Related: rhbz#1991688

* Fri Apr 16 2021 Mohan Boddu <mboddu@redhat.com> - 0.0.4-12
- Rebuilt for RHEL 9 BETA on Apr 15th 2021. Related: rhbz#1947937

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.4-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.4-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 14 2020 Tom Stellard <tstellar@redhat.com> - 0.0.4-9
- Use make macros
- https://fedoraproject.org/wiki/Changes/UseMakeBuildInstallMacro

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.4-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.4-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.4-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jan 25 2019 Jonathan Wakely <jwakely@redhat.com> - 0.0.4-5
- Rebuilt for Boost 1.69

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Tue Jan 23 2018 Jonathan Wakely <jwakely@redhat.com> - 0.0.4-2
- Rebuilt for Boost 1.66

* Tue Jan 09 2018 David Tardon <dtardon@redhat.com> - 0.0.4-1
- new upstream release

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.3-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.3-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Mon Jul 03 2017 Jonathan Wakely <jwakely@redhat.com> - 0.0.3-5
- Rebuilt for Boost 1.64

* Mon May 15 2017 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Jan 27 2017 Jonathan Wakely <jwakely@redhat.com> - 0.0.3-2
- Rebuilt for Boost 1.63

* Thu Mar 03 2016 David Tardon <dtardon@redhat.com> - 0.0.3-1
- new upstream release

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.0.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 15 2016 Jonathan Wakely <jwakely@redhat.com> - 0.0.2-8
- Rebuilt for Boost 1.60

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 0.0.2-7
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.2-6
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 0.0.2-5
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 0.0.2-3
- Rebuilt for GCC 5 C++11 ABI change

* Tue Jan 27 2015 Petr Machata <pmachata@redhat.com> - 0.0.2-2
- Rebuild for boost 1.57.0

* Fri Dec 05 2014 David Tardon <dtardon@redhat.com> - 0.0.2-1
- new upstream release

* Thu Aug 21 2014 David Tardon <dtardon@redhat.com> - 0.0.1-1
- new upstream release

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Jun 26 2014 David Tardon <dtardon@redhat.com> 0.0.0-1
- initial import
